""" apu.datetime: anton python utils datetime module """

__version__ = (0, 0, 1)
__email__ = "anton.feldmann@gmail.com"
__author__ = "anton feldmann"

from apu.time.date_time import DateTime
from apu.time.timer import time_it

__all__ = ['DateTime', "time_it"]
